<script context="module"></script>

<script>import { browser } from "$app/environment";
import { createEventDispatcher, onMount } from "svelte";
import watchWindowValue from "@cloudparker/easy-window-watcher";
export let height;
export let width;
export let image;
export let aspectRatio = 0;
export let cropperUrl = "https://unpkg.com/cropperjs@2.0.0-beta.2/dist/cropper.min.js";
let cropper;
let cropperCanvas;
let cropperSelection;
let dispatch = createEventDispatcher();
let mimetypes = {
  png: "image/png",
  jpeg: "image/jpeg",
  webp: "image/webp"
};
export async function crop({
  width: width2,
  height: height2,
  format = "png",
  quality = 1,
  blob = false
}) {
  let result = null;
  if (cropperSelection) {
    let canvas = await cropperSelection.$toCanvas({ width: width2, height: height2 });
    if (canvas) {
      if (blob) {
        result = await new Promise((resolve) => {
          canvas.toBlob(
            (blobData) => {
              resolve(blobData);
            },
            mimetypes[format] || "image/png",
            quality || 1
          );
        });
      } else {
        result = canvas.toDataURL(mimetypes[format] || "image/png", quality || 1);
      }
    }
  }
  if (result) {
    dispatch("crop", result);
  }
  return result;
}
function init() {
  if (Cropper) {
    cropper = new Cropper.default(image, {
      container: ".cropper-container"
    });
    cropperCanvas = cropper.getCropperCanvas();
    cropperSelection = cropper.getCropperSelection();
    updateCropper();
    dispatch("cropper", cropper);
  }
}
function updateCropper(..._) {
  console.log(cropperCanvas);
  if (cropperCanvas) {
    cropperCanvas.style.width = `${width}px`;
    cropperCanvas.style.height = `${height}px`;
  }
  if (cropperSelection) {
    if (aspectRatio) {
      cropperSelection.initialAspectRatio = aspectRatio;
      cropperSelection.aspectRatio = aspectRatio;
    }
    cropperSelection.$center();
  }
}
onMount(() => {
  if (browser) {
    watchWindowValue("Cropper").then((Cropper2) => {
      console.log(Cropper2);
      init();
    });
  }
});
$:
  updateCropper(width, height);
</script>

<svelte:head>
	{#if browser && !window['Cropper']}
		<script src={cropperUrl}></script>
	{/if}
</svelte:head>

<div class="cropper-container" style="width:{width}px; height:{height}px;" />

<style>
	.cropper-container {
	}
</style>
